@@ -193,9 +193,9 @@ sub setup_aws_security {
       $c="aws ec2 modify-instance-attribute --instance-id $i ".
          "--groups $g";
       ($hash,$output,$error)=run_aws_cmd($c);
-      my $c="aws ec2 describe-instances --instance-ids $i";
+      $c="aws ec2 describe-instances --instance-ids $i";
       ($hash,$output,$error)=run_aws_cmd($c);
-      my $sg=$hash->{Reservations}->[0]->{Instances}->[0]
+      $sg=$hash->{Reservations}->[0]->{Instances}->[0]
                   ->{SecurityGroups}->[0]->{GroupName};
       print "\n   NEW SECURITY GROUP -> $sg\n\n";
       return "$sg assigned to this host",'';
